@@ -1,16 +1,17 @@
 package Test::Role::TinyCommons::Tree;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-02'; # DATE
-our $DIST = 'Role-TinyCommons-Tree'; # DIST
-our $VERSION = '0.127'; # VERSION
-
 use strict;
 use warnings;
 use Test::Exception;
 use Test::More 0.98;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-07'; # DATE
+our $DIST = 'Role-TinyCommons-Tree'; # DIST
+our $VERSION = '0.128'; # VERSION
+
 our @EXPORT_OK = qw(test_role_tinycommons_tree);
 
 sub test_role_tinycommons_tree {
@@ -346,7 +347,7 @@ Test::Role::TinyCommons::Tree - Test suite for Role::TinyCommons::Tree
 
 =head1 VERSION
 
-This document describes version 0.127 of Test::Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2021-07-02.
+This document describes version 0.128 of Test::Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2021-10-07.
 
 =head1 DESCRIPTION
 
@@ -416,7 +417,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Role-TinyC
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-TreeNode>.
+Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-Tree>.
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2016 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS
 
@@ -426,15 +455,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2016 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
